#!/bin/bash
#
# Configure all of VBooking for WAS and DB2
#

# Functions
check_prereqs () {
	./vbooking/scripts/install/VBooking-prereqs.sh 2>&1 >$SCRIPT_ROOT_PATH/VBooking-prereqs.log
	if [ $? -ne 0 ]; then
		PREREQ_CHECK=1
	fi
}

install_vb_queues () {
	./vbooking/scripts/install/VBooking-queues.sh 2>&1 >$SCRIPT_ROOT_PATH/VBooking-queues.log
}

install_vb_db () {
	./vbooking/scripts/install/VBooking-database.sh 2>&1 >$SCRIPT_ROOT_PATH/VBooking-database.log
}

install_vb_tomcat () {
	./vbooking/scripts/install/VBooking-tomcat.sh 2>&1 >$SCRIPT_ROOT_PATH/VBooking-tomcat.log	
}

install_vb_activemq () {
	./vbooking/scripts/install/VBooking-activemq.sh 2>&1 >$SCRIPT_ROOT_PATH/VBooking-activemq.log	
}

install_vb_was () {
	./vbooking/scripts/install/VBooking-WAS.sh 2>&1 >$SCRIPT_ROOT_PATH/VBooking-WAS.log
}

install_vb_standalone () {
	./vbooking/scripts/install/VBooking-standalone.sh 2>&1 >$SCRIPT_ROOT_PATH/VBooking-standalone.log
}

install_vb_scripts () {
	./vbooking/scripts/install/VBooking-scripts.sh 2>&1 >$SCRIPT_ROOT_PATH/VBooking-scripts.log
}

install_vb_schemas () {
	./vbooking/scripts/install/VBooking-schemas.sh 2>&1 >$SCRIPT_ROOT_PATH/VBooking-schemas.log
}

init_db () {
	if id -u $USERNAME_DB2_INSTANCE >/dev/null 2>&1; then
		su - $USERNAME_DB2_INSTANCE <<ENDSCRIPT
		/opt/vbooking/scripts/db2/resetDB2.sh
ENDSCRIPT
	fi
}

install_vb_documentation () {
	./vbooking/scripts/install/VBooking-documentation.sh 2>&1 >$SCRIPT_ROOT_PATH/VBooking-documentation.log
}

# Main 
echo "*** VBooking Installation Script ***"
SCRIPT_ROOT_PATH="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"
echo "Script executed from $SCRIPT_ROOT_PATH" 

# if [[ $EUID -ne 0 ]]; then
	# echo "This script must be executed by a user with root privileges"
	# exit 1
# fi

chmod +x $SCRIPT_ROOT_PATH/vbooking/scripts/install/*.sh
source $SCRIPT_ROOT_PATH/installer-variables-linux.conf

cd $SCRIPT_ROOT_PATH

#MT: Removed this warning, as it was getting in the way of doing an automated install (25 Mar 2015)
#echo "You should update the installer variables before using the script. Do you want to continue?"
#select yn in "Continue" "Exit"; do
#    case $yn in
#        Continue ) break;;
#        Exit ) exit;;
#    esac
#done
echo "Checking prerequisites... "
PREREQ_CHECK=0
check_prereqs
if [ $PREREQ_CHECK -ne 0 ]; then
	echo "Prerequisite check failed. See VBooking-prereqs.log for more details."
	exit 1
fi
if [ $INSTALL_TOMCAT = "Y" ]; then
	echo "Installing Tomcat for VBooking"
	install_vb_tomcat
fi
if [ $INSTALL_ACTIVEMQ = "Y" ]; then
	echo "Installing ActiveMQ for VBooking"
	install_vb_activemq
fi
if [ $CONFIGURE_VBOOKING_MQ_QUEUES = "Y" ]; then
	echo "Creating Websphere MQ queues"
	install_vb_queues
fi
if [ $INSTALL_VBOOKING_DATABASE = "Y" ]; then
	echo "Creating VBOOKING and VBEXRATE databases"
	install_vb_db
fi
if [ $INSTALL_VBOOKING_WAS = "Y" ]; then
	echo "Installing WebSphere Application Server components"
	install_vb_was
fi
if [ $INSTALL_VBOOKING_STANDALONE_APPS = "Y" ]; then
	echo "Installing standalone apps for VBooking"
	install_vb_standalone
fi
if [ $INSTALL_VBOOKING_SCRIPTS = "Y" ]; then
	echo "Installing VBooking scripts"
	install_vb_scripts
fi
if [ $INSTALL_VBOOKING_SCHEMAS = "Y" ]; then
	echo "Installing VBooking XSDs and copybook"
	install_vb_schemas
fi
if [ -x /opt/vbooking/scripts/db2/resetDB2.sh ] && [ $INITIALIZE_VBOOKING_DATABASE = "Y" ]; then
	echo "Initializing databases with default data"
	init_db
fi

echo "Installing Vbooking documentation"
install_vb_documentation

echo "Vacation Booking installation complete."
echo "If you would like to install RIT Integrations for Vacation Booking, run RIT_Integrations.sh"
