#!/bin/bash
#
# Add RIT integrations for all parts of Vacation Booking
#

# Functions
check_prereqs () {
	./vbooking/scripts/install/VBooking-prereqs.sh 2>&1 >$SCRIPT_ROOT_PATH/RIT-prereqs.log
	if [ $? -ne 0 ]; then
		PREREQ_CHECK=1
	fi
}

extract_tools () {
	./vbooking/scripts/RIT-integration/Tools-Extract.sh 2>&1 >>$SCRIPT_ROOT_PATH/VBooking-RIT-integration.log
}

install_mq_exit () {
	echo "WebSphere MQ: Installing RIT MQ exit"
	./vbooking/scripts/RIT-integration/MQ-Exit-Install-64.sh 2>&1 >>$SCRIPT_ROOT_PATH/VBooking-RIT-integration.log
}

install_tomcat_integrations () {
	echo "Tomcat: Installing RIT JDBC driver"
	./vbooking/scripts/RIT-integration/Tomcat-JDBC-Install.sh 2>&1 >$SCRIPT_ROOT_PATH/VBooking-RIT-integration.log
	echo "Tomcat: Installing RIT HTTP proxy"
	./vbooking/scripts/RIT-integration/Tomcat-Proxy-Install.sh 2>&1 >>$SCRIPT_ROOT_PATH/VBooking-RIT-integration.log
	echo "Tomcat: Installing RIT Java agent"
	./vbooking/scripts/RIT-integration/Tomcat-JavaVirt-Install.sh 2>&1 >>$SCRIPT_ROOT_PATH/VBooking-RIT-integration.log
}

install_was_integrations () {
	echo "WebSphere Application Server: Installing RIT HTTP proxy" 
	./vbooking/scripts/RIT-integration/WAS-Proxy-Install.sh 2>&1 >>$SCRIPT_ROOT_PATH/VBooking-RIT-integration.log
	echo "WebSphere Application Server: Installing RIT JDBC Driver"
	cp -R $TOOLS_PATH/Java/JDBC /opt/IBM/WebSphere/AppServer/RTW-JDBC 
	mv /opt/IBM/WebSphere/AppServer/RTW-JDBC/registration.xml /opt/IBM/WebSphere/AppServer/RTW-JDBC/registration.xml.backup
    cat /opt/IBM/WebSphere/AppServer/RTW-JDBC/registration.xml.backup | tr '\n' '\r' | sed -e 's|<!--[^<]*<identifier[^-]*-->|<identifier\ name=\"WebSphere\ Application\ Server\"\/>|' | tr '\r' '\n' > /opt/IBM/WebSphere/AppServer/RTW-JDBC/registration.xml
	/opt/IBM/WebSphere/AppServer/profiles/AppSrv01/bin/wsadmin.sh -f /opt/IBM/WebSphere/AppServer/RTW-JDBC/WebSphere/setupJDBCProvider.py /opt/IBM/WebSphere/AppServer/RTW-JDBC/
}

install_java_integrations () {
	echo "Flight Confirmation Server: Installing RIT Java agent"
	./vbooking/scripts/RIT-integration/JavaVirt-Install.sh 2>&1 >>$SCRIPT_ROOT_PATH/VBooking-RIT-integration.log
	echo "Currency Server: Installing RIT JDBC driver"
	./vbooking/scripts/RIT-integration/Standalone-JDBC-Install.sh 2>&1 >>$SCRIPT_ROOT_PATH/VBooking-RIT-integration.log
}

# Main 
echo "*** VBooking Installation Script ***"
SCRIPT_ROOT_PATH="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"
echo "Script executed from $SCRIPT_ROOT_PATH" 

if [[ $EUID -ne 0 ]]; then
	echo "This script must be executed by a user with root privileges"
	exit 1
fi

chmod +x $SCRIPT_ROOT_PATH/vbooking/scripts/RIT-integration/*.sh
source $SCRIPT_ROOT_PATH/installer-variables-linux.conf

cd $SCRIPT_ROOT_PATH


if [[ $EUID -ne 0 ]]; then
	echo "This script must be executed by a user with root privileges"
	exit 1
fi

echo "Checking prerequisites... "
PREREQ_CHECK=0
check_prereqs
if [ $PREREQ_CHECK -ne 0 ]; then
	echo "Prerequisite check failed. See RIT-prereqs.log for more details."
	exit 1
fi

extract_tools

# For now, we'll assume that all integrations are being installed, as long as the related software is being used.  
# E.g., Tomcat integrations will be installed if Tomcat is meant to be installed.


if [ $CONFIGURE_VBOOKING_MQ_QUEUES = "Y" ]; then
	install_mq_exit
fi
if [ $INSTALL_TOMCAT = "Y" ]; then
	install_tomcat_integrations
fi
if [ $INSTALL_VBOOKING_WAS = "Y" ]; then
	install_was_integrations
fi
if [ $INSTALL_VBOOKING_STANDALONE_APPS = "Y" ]; then
	install_java_integrations
fi

echo "Vacation Booking installation complete."
