#
# Script to configure WAS for the Vacation Booking app
#

import sys
import string
import shutil
import os

cell = java.lang.System.getenv('WAS_CELL')
cellId = AdminConfig.list('Cell')
node = java.lang.System.getenv('WAS_NODE')
hostname = sys.argv[0]
db2Path = sys.argv[1]
mqQMname = sys.argv[2]
mqQMport = sys.argv[3]
mqWebapp = sys.argv[4]
db2user = sys.argv[5]
db2pass = sys.argv[6]
db2schema = sys.argv[7]
frequentflyerURL = sys.argv[8]
availableSeatsURL = sys.argv[9]
configureCICS = sys.argv[10]
serverName = sys.argv[11]
serverURL = sys.argv[12]
programName = sys.argv[13]
scriptRootFolder = sys.argv[14]
cicsJarPath = sys.argv[15]
pathWAS = sys.argv[16]
nameWAS = sys.argv[17]

#
# Create the DB2 JDBC provider
#

AdminTask.setVariable(['-variableName','DB2_JCC_DRIVER_PATH','-variableValue',db2Path+'/java'])
AdminTask.setVariable(['-variableName','UNIVERSAL_JDBC_DRIVER_PATH','-variableValue',db2Path+'/java'])
AdminTask.setVariable(['-variableName','DB2_JCC_DRIVER_PATH','-variableValue',db2Path+'/java','-scope','Cell='+cell+',Node='+node])
AdminTask.setVariable(['-variableName','UNIVERSAL_JDBC_DRIVER_PATH','-variableValue',db2Path+'/java','-scope','Cell='+cell+',Node='+node])

alias = cell + '/VBookingUser'
security = AdminConfig.list('Security')
AdminConfig.create('JAASAuthData', security, [['alias',alias],['userId',db2user],['password',db2pass]])

AdminTask.createJDBCProvider(['-scope','Cell='+cell,'-databaseType','DB2','-providerType','DB2 Using IBM JCC Driver','-implementationType','XA data source','-name','DB2 Using IBM JCC Driver (XA)'])
provider = AdminConfig.getid("/Cell:" + cell + '/JDBCProvider:DB2 Using IBM JCC Driver (XA)/')
jdbcDataSource = AdminTask.createDatasource(provider, ['-name','VBooking XA DataSource','-jndiName','jdbc/vbooking','-dataStoreHelperClassName','com.ibm.websphere.rsadapter.DB2UniversalDataStoreHelper','-componentManagedAuthenticationAlias',alias,'-xaRecoveryAuthAlias',alias,'-configureResourceProperties', '[[databaseName java.lang.String VBOOKING] [driverType java.lang.Integer 4] [serverName java.lang.String ' + hostname + '] [portNumber java.lang.Integer 50000]]'])

# Set the db2 schema as the default schema
jdbcPropertySet = AdminConfig.showAttribute(jdbcDataSource, 'propertySet')
jdbcResourceProperties = AdminConfig.showAttribute(jdbcPropertySet, 'resourceProperties')
propertyArray = jdbcResourceProperties[1:len(jdbcResourceProperties)-1].split(' ')
for resourceProperty in propertyArray:
    name = AdminConfig.showAttribute(resourceProperty, 'name')
    if name == 'currentSchema':
        AdminConfig.modify(resourceProperty, [['value', db2schema.upper()]])
        break


#
# Set up the MQ resources
#

mqConn = [['qmgrHostname',hostname],['qmgrName',mqQMname],['qmgrPortNumber',mqQMport],['qmgrSvrconnChannel',mqWebapp]]
AdminJMS.createWMQConnectionFactory(cellId,mqQMname,'jms/ConnectionFactory',mqConn)

configList = []
configList.append(['vbooking.booking','eis/jms/booking','eis/BookingProcessor'])
configList.append(['vbooking.payment.multinational','eis/jms/vbooking/payment/multinational','eis/MultinationalProcessor'])
configList.append(['vbooking.payment.multinational.reply','eis/jms/vbooking/payment/reply/multinational',None])
configList.append(['vbooking.payment.global','eis/jms/vbooking/payment/global','eis/GlobalProcessor'])
configList.append(['vbooking.payment.global.reply','eis/jms/vbooking/payment/reply/global',None])
configList.append(['vbooking.payment.worldwide','eis/jms/vbooking/payment/worldwide','eis/WorldwideProcessor'])
configList.append(['vbooking.payment.worldwide.reply','eis/jms/vbooking/payment/reply/worldwide',None])
configList.append(['vbooking.reservations','eis/jms/reservations','eis/BookingReservations'])
for config in configList:
  queue=config[0]
  jndiName=config[1]
  AdminJMS.createWMQQueue(cellId, queue, jndiName, queue, [])
  if config[2]:
    specJNDIName=config[2]
    AdminJMS.createWMQActivationSpec(cellId,queue,specJNDIName,jndiName,'javax.jms.Queue',mqConn)

AdminResources.createURL(node, "server1", "Default URL Provider", "FrequentFlyerURL", "jms/vbooking/frequentflyerURL", frequentflyerURL)
AdminResources.createURL(node, "server1", "Default URL Provider", "AvailableSeatsURL", "jms/vbooking/availableSeatsURL", availableSeatsURL)

#
# Set up CICS System Properties
#
if configureCICS == 'Y':
  myServer = AdminConfig.getid('/Server:server1/')
  jvm = AdminConfig.list("JavaVirtualMachine", myServer)
  attrs = [["name", "flightrest.flyCheckMethod"], ["value", "CICS"]]
  AdminConfig.create("Property", jvm, attrs, "systemProperties")
  attrs = [["name", "GatewayServerName"], ["value", serverName]]
  AdminConfig.create("Property", jvm, attrs, "systemProperties")
  attrs = [["name", "GatewayURL"], ["value", serverURL]]
  AdminConfig.create("Property", jvm, attrs, "systemProperties")
  attrs = [["name", "ProgramName"], ["value", programName]]
  AdminConfig.create("Property", jvm, attrs, "systemProperties")
  
  

#
# Install the Vacation Booking app
#
AdminApplication.installAppWithDefaultBindingOption('vbooking.booking.app',scriptRootFolder + '/vbooking/WAS/com.vbooking.booking.app.ear',node,'server1','jdbc/vbooking',db2user,db2pass,'jms/ConnectionFactory','bob','default_host')
AdminApplication.installAppWithDefaultBindingOption('vbooking.mybooking.app',scriptRootFolder + '/vbooking/WAS/com.vbooking.mybooking.ear',node,'server1','jdbc/vbooking',db2user,db2pass,'jms/ConnectionFactory','bob','default_host')
AdminApplication.installAppWithDefaultBindingOption('vbooking.payment.app',scriptRootFolder + '/vbooking/WAS/com.vbooking.payment.app.ear',node,'server1','jdbc/vbooking',db2user,db2pass,'jms/ConnectionFactory','bob','default_host')
AdminApplication.installAppWithDefaultBindingOption('vbooking.flights.app',scriptRootFolder + '/vbooking/WAS/com.vbooking.flights.rest.app.ear',node,'server1','jdbc/vbooking',db2user,db2pass,'jms/ConnectionFactory','bob','default_host')
AdminApplication.installAppWithDefaultBindingOption('vbooking.reservations.app',scriptRootFolder + '/vbooking/WAS/com.vbooking.reservations.app.ear',node,'server1','jdbc/vbooking',db2user,db2pass,'jms/ConnectionFactory','bob','default_host')


AdminConfig.save()

# Move CICS jar into Websphere
if configureCICS == 'Y':
    shutil.copy(os.path.join(cicsJarPath, 'ctgclient.jar'), os.path.join(pathWAS, 'profiles', nameWAS, 'installedApps', cell, 'vbooking.flights.app.ear', 'lib'))
    
