@echo off
rem
rem Setup tomcat and configure the apps within it
rem

echo Installing and configuring Tomcat....

SET SCRIPT_PATH=%~dp0
SET CURRENT_PATH=%cd%

cd "%SCRIPT_PATH%"

rem Should a new tomcat folder be installed?
call Utils.bat readConfYN USE_PRE_INSTALLED_TOMCAT N
call Utils.bat readConf TOMCAT_PATH
call Utils.bat readConf TOMCAT_ZIP
call Utils.bat readConf TOMCAT_ZIP_SUB_FOLDER
call Utils.bat readConf TOMCAT_SERVICE_NAME
call Utils.bat readConf TOMCAT_VERSION
call Utils.bat readConfYN TOMCAT_PREINSTALLED_AS_WINDOWS_SERVICE N

SET tcFolder=%TOMCAT_PATH%
if %USE_PRE_INSTALLED_TOMCAT% == N (
	echo Installing Tomcat to %TOMCAT_PATH%
	cscript Utils.vbs UnzipIt "%CURRENT_PATH%\%TOMCAT_ZIP%" %TOMCAT_PATH%
)
REM redirect tcFolder to sub folder location?
IF EXIST %TOMCAT_PATH%\%TOMCAT_ZIP_SUB_FOLDER% (
	set tcFolder=%TOMCAT_PATH%\%TOMCAT_ZIP_SUB_FOLDER%
)

if Not Exist "%tcFolder%" (
	echo Unable to proceed without valid Tomcat installation.
	exit /b 1
)
echo Copying web apps to tomcat.
copy /y "%CURRENT_PATH%\vbooking\tomcat\*.war" "%tcFolder%\webapps"

echo Configuring Tomcat port
call Utils.bat readConf TOMCAT_PORT
echo Replacing 8080 with %TOMCAT_PORT%
cscript Utils.vbs ReplaceToken "%tcFolder%"\conf\server.xml 8080 %TOMCAT_PORT%

call Utils.bat readConf PATH_WAS_HOME
call Utils.bat readConf JAVA_7_HOME
IF DEFINED JAVA_7_HOME (
	set "JAVA_HOME=%JAVA_7_HOME%"
	SETX /M JAVA_HOME "%JAVA_7_HOME%"
	echo Using specified Java install
) ELSE (
 	IF NOT DEFINED JAVA_HOME (
	set "JAVA_HOME=%PATH_WAS_HOME%\java"
	SETX /M JAVA_HOME "%PATH_WAS_HOME%\java"
	echo Using WAS Java install
))

echo Starting Tomcat to install Vacation Booking webapps...
cd /d "%tcFolder%"\bin
if %TOMCAT_PREINSTALLED_AS_WINDOWS_SERVICE% == N (
	call startup.bat
) ELSE (
	call tomcat%TOMCAT_VERSION% start %TOMCAT_SERVICE_NAME%
)
echo A one minute timeout is set to allow Tomcat to start and extract the WAR files. Press any key if you're sure Tomcat has already started.>con
timeout 60
echo Stopping Tomcat.
if %TOMCAT_PREINSTALLED_AS_WINDOWS_SERVICE% == N (
	call shutdown.bat
) ELSE (
	call tomcat%TOMCAT_VERSION% stop %TOMCAT_SERVICE_NAME%
)
echo A 30 second timeout is set to allow Tomcat to stop fully. Press any key if you're sure Tomcat has already stopped.>con
timeout 30
cd /d "%SCRIPT_PATH%"

echo Updating webapp configurations
call Utils.bat readConf HOST
if %HOST%==localhost ( 
	REM no change to host
	goto:doneHost 
)
echo Changing localhost to %HOST%
cscript Utils.vbs ReplaceToken "%tcFolder%"\webapps\vbooking-admin\META-INF\context.xml localhost %HOST%
cscript Utils.vbs ReplaceToken "%tcFolder%"\webapps\vbooking-home\META-INF\context.xml localhost %HOST%
cscript Utils.vbs ReplaceToken "%tcFolder%"\webapps\vbooking-admin\WEB-INF\web.xml localhost %HOST%
cscript Utils.vbs ReplaceToken "%tcFolder%"\webapps\vbooking-home\WEB-INF\web.xml localhost %HOST%
REM Some files may not exist (most likely to happen on Tomcat 7):
if exist "%tcFolder%"\conf\Catalina\localhost\vbooking-admin.xml (
	cscript Utils.vbs ReplaceToken %tcFolder\conf\Catalina\localhost\vbooking-admin.xml localhost %HOST%
)
if exist "%tcFolder%"\conf\Catalina\localhost\vbooking-home.xml (
	cscript Utils.vbs ReplaceToken %tcFolder\conf\Catalina\localhost\vbooking-home.xml localhost %HOST%
)
:doneHost
call Utils.bat readConf USE_FF_VERSION
echo setting Frequent Flyer to %USE_FF_VERSION%
cscript Utils.vbs ReplaceToken "%tcFolder%"\webapps\vbooking-home\WEB-INF\web.xml FFVALUE %USE_FF_VERSION%

if %TOMCAT_PORT%==8089 ( 
	REM No change to port
	goto:donePort 
)
cscript Utils.vbs ReplaceToken "%tcFolder%"\webapps\vbooking-admin\META-INF\context.xml 8089 %TOMCAT_PORT%
cscript Utils.vbs ReplaceToken "%tcFolder%"\webapps\vbooking-home\META-INF\context.xml 8089 %TOMCAT_PORT%
cscript Utils.vbs ReplaceToken "%tcFolder%"\webapps\vbooking-admin\WEB-INF\web.xml 8089 %TOMCAT_PORT%
cscript Utils.vbs ReplaceToken "%tcFolder%"\webapps\vbooking-home\WEB-INF\web.xml 8089 %TOMCAT_PORT%
REM Some files may not exist (most likely to happen on Tomcat 7):
if exist "%tcFolder%"\conf\Catalina\localhost\vbooking-admin.xml (
	cscript Utils.vbs ReplaceToken %tcFolder\conf\Catalina\localhost\vbooking-admin.xml 8089 %TOMCAT_PORT%
)
if exist "%tcFolder%"\conf\Catalina\localhost\vbooking-home.xml (
	cscript Utils.vbs ReplaceToken %tcFolder\conf\Catalina\localhost\vbooking-home.xml 8089 %TOMCAT_PORT%
)
:donePort

echo Copying DB2 Drivers into Tomcat
REM set's DB2_PATH
call Utils.bat CheckSetDB2Path 
copy /y "%DB2_PATH%"\java\db2jcc4.jar "%tcFolder%"\lib

echo Configuring DB2 Connection in Tomcat
call Utils.bat readConf USERNAME_DB2_VBOOKING
call Utils.bat readConf PASSWORD_DB2_VBOOKING
call Utils.bat readConf PORT_DB2_INSTANCE
rem JDBC Driver for VBooking
if %TOMCAT_PREINSTALLED_AS_WINDOWS_SERVICE% == Y (
	call %tcFolder%\bin\tomcat%TOMCAT_VERSION% //US//%TOMCAT_SERVICE_NAME% ++JvmOptions=-Djdbc.drivers=com.ibm.db2.jcc.DB2Driver;-Djdbc.url=jdbc:db2://localhost:%PORT_DB2_INSTANCE%/VBOOKING;-Djdbc.username=%USERNAME_DB2_VBOOKING%;-Djdbc.password=%PASSWORD_DB2_VBOOKING%
) ELSE (
(
echo SET JAVA_OPTS=-Djdbc.drivers=com.ibm.db2.jcc.DB2Driver
echo SET JAVA_OPTS=%%JAVA_OPTS%% -Djdbc.url=jdbc:db2://localhost:%PORT_DB2_INSTANCE%/VBOOKING -Djdbc.username=%USERNAME_DB2_VBOOKING% -Djdbc.password=%PASSWORD_DB2_VBOOKING%
echo REM SET JAVA_OPTS=%%JAVA_OPTS%% -Dhttp.proxyHost=localhost -Dhttp.proxyPort=3128 -Dhttp.nonProxyHosts=
) >> "%tcFolder%"\bin\setenv.bat
)

echo Moving Websphere MQ jars to tomcat
copy /y "%PATH_WAS_HOME%"\installedConnectors\wmq.jmsra.rar\*.jar "%tcFolder%"\webapps\vbooking-admin\WEB-INF\lib
copy /y "%PATH_WAS_HOME%"\installedConnectors\wmq.jmsra.rar\*.jar "%tcFolder%"\webapps\vbooking-home\WEB-INF\lib

echo Starting Tomcat
cd /d "%tcFolder%"\bin
if %TOMCAT_PREINSTALLED_AS_WINDOWS_SERVICE% == N (
	call startup.bat
) ELSE (
	call tomcat%TOMCAT_VERSION% start %TOMCAT_SERVICE_NAME%
)
cd /d "%SCRIPT_PATH%"

echo Tomcat installed and configured!
