#!/bin/bash
#
# Setup tomcat and configure the apps within it
#

echo "Installing and configuring Tomcat...."
THIS_SCRIPT_PATH="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"
TEMP_PATH="$( cd "$( dirname "${THIS_SCRIPT_PATH}" )" && pwd )"
TEMP_PATH="$( cd "$( dirname "${TEMP_PATH}" )" && pwd )"
SCRIPT_ROOT_PATH="$( cd "$( dirname "${TEMP_PATH}" )" && pwd )"
source $SCRIPT_ROOT_PATH/installer-variables-linux.conf

echo "Unzipping Tomcat"
mkdir -p $TOMCAT_PATH
unzip -o $SCRIPT_ROOT_PATH/$TOMCAT_ZIP -d /tmp/tomcat
mv /tmp/tomcat/${TOMCAT_ZIP%.zip}/* $TOMCAT_PATH
rmdir /tmp/tomcat/${TOMCAT_ZIP%.zip}
rmdir /tmp/tomcat

echo "Copying Vacation Booking webapps"
cp $SCRIPT_ROOT_PATH/vbooking/tomcat/*.war $TOMCAT_PATH/webapps/
chmod +x $TOMCAT_PATH/bin/*.sh

echo "Configuring Tomcat port"
sed -i.bak s/8080/$TOMCAT_PORT/g $TOMCAT_PATH/conf/server.xml

if [ -n "$JAVA_7_HOME" ]; then 
	export JAVA_HOME=$JAVA_7_HOME
	echo "Using specified Java install"
else
	export JAVA_HOME=/opt/IBM/WebSphere/AppServer/java
	echo "Using WAS Java install"
fi
echo "Starting Tomcat to install Vacation Booking webapps"
$TOMCAT_PATH/bin/startup.sh
sleep 1m
echo "Stopping Tomcat"
$TOMCAT_PATH/bin/shutdown.sh

echo "Updating webapp configurations"
sed -i.bak s/localhost/$HOST/g $TOMCAT_PATH/webapps/vbooking-admin/META-INF/context.xml
sed -i.bak s/localhost/$HOST/g $TOMCAT_PATH/webapps/vbooking-home/META-INF/context.xml
sed -i.bak s/localhost/$HOST/g $TOMCAT_PATH/webapps/vbooking-admin/WEB-INF/web.xml
sed -i.bak s/localhost/$HOST/g $TOMCAT_PATH/webapps/vbooking-home/WEB-INF/web.xml
sed -i.bak s/FFVALUE/$USE_FF_VERSION/g $TOMCAT_PATH/webapps/vbooking-home/WEB-INF/web.xml
# Some files may not exist (most likely to happen on Tomcat 7):
if [ -e $TOMCAT_PATH/conf/Catalina/localhost/vbooking-admin.xml ]; then
	sed -i.bak s/localhost/$HOST/g $TOMCAT_PATH/conf/Catalina/localhost/vbooking-admin.xml
fi
if [ -e $TOMCAT_PATH/conf/Catalina/localhost/vbooking-home.xml ]; then
	sed -i.bak s/localhost/$HOST/g $TOMCAT_PATH/conf/Catalina/localhost/vbooking-home.xml
fi

sed -i.bak s/8089/$TOMCAT_PORT/g $TOMCAT_PATH/webapps/vbooking-admin/META-INF/context.xml
sed -i.bak s/8089/$TOMCAT_PORT/g $TOMCAT_PATH/webapps/vbooking-home/META-INF/context.xml
sed -i.bak s/8089/$TOMCAT_PORT/g $TOMCAT_PATH/webapps/vbooking-admin/WEB-INF/web.xml
sed -i.bak s/8089/$TOMCAT_PORT/g $TOMCAT_PATH/webapps/vbooking-home/WEB-INF/web.xml
if [ -e $TOMCAT_PATH/conf/Catalina/localhost/vbooking-admin.xml ]; then
	sed -i.bak s/8089/$TOMCAT_PORT/g $TOMCAT_PATH/conf/Catalina/localhost/vbooking-admin.xml
fi
if [ -e $TOMCAT_PATH/conf/Catalina/localhost/vbooking-home.xml ]; then
	sed -i.bak s/8089/$TOMCAT_PORT/g $TOMCAT_PATH/conf/Catalina/localhost/vbooking-home.xml
fi

echo "Copying Websphere MQ jars into Tomcat"
cp $PATH_WAS_HOME/installedConnectors/wmq.jmsra.rar/*.jar $TOMCAT_PATH/webapps/vbooking-admin/WEB-INF/lib
cp $PATH_WAS_HOME/installedConnectors/wmq.jmsra.rar/*.jar $TOMCAT_PATH/webapps/vbooking-home/WEB-INF/lib


echo "Copying DB2 Drivers into Tomcat"
#Find the DB2 install location, and copy over the drivers
A=$(/usr/local/bin/db2ls -c | cut -d : -f 1)
DB2_PATH=${A:6}
cp $DB2_PATH/java/db2jcc4.jar $TOMCAT_PATH/lib

echo "Configuring DB2 Connection in Tomcat"
#JDBC Driver for VBooking
if [ ! -f $TOMCAT_PATH/bin/setenv.sh ]
then
  echo "#!/bin/bash" >> $TOMCAT_PATH/bin/setenv.sh
fi
echo "JAVA_OPTS=\"-Djdbc.drivers=com.ibm.db2.jcc.DB2Driver\"" >> $TOMCAT_PATH/bin/setenv.sh
echo "JAVA_OPTS=\"\$JAVA_OPTS -Djdbc.url=jdbc:db2://localhost:$PORT_DB2_INSTANCE/VBOOKING -Djdbc.username=$USERNAME_DB2_VBOOKING -Djdbc.password=$PASSWORD_DB2_VBOOKING\"" >> $TOMCAT_PATH/bin/setenv.sh
echo "#JAVA_OPTS=\"\$JAVA_OPTS -Dhttp.proxyHost=localhost -Dhttp.proxyPort=3128 -Dhttp.nonProxyHosts=\"" >> $TOMCAT_PATH/bin/setenv.sh
echo "export JAVA_OPTS=\$JAVA_OPTS" >> $TOMCAT_PATH/bin/setenv.sh
chmod 744 $TOMCAT_PATH/bin/setenv.sh

echo "Adding Tomcat user and group"
if ! id -g $USERGROUP_TOMCAT >/dev/null 2>&1; then
	groupadd $USERGROUP_TOMCAT
fi
if ! id -u $USERNAME_TOMCAT >/dev/null 2>&1; then
	useradd -g $USERGROUP_TOMCAT -M -s /sbin/nologin -d $TOMCAT_PATH $USERNAME_TOMCAT
fi
chown -R $USERNAME_TOMCAT:$USERGROUP_TOMCAT $TOMCAT_PATH
usermod -a -G $USERGROUP_TOMCAT $USER
chmod -R g+w $TOMCAT_PATH

echo "Setting up service vbtomcat"
sed -i.bak s@^INSTALLPATH=.*@INSTALLPATH=$TOMCAT_PATH/bin@g $SCRIPT_ROOT_PATH/vbooking/scripts/services/vbtomcat
chmod +x $SCRIPT_ROOT_PATH/vbooking/scripts/services/vbtomcat
cp $SCRIPT_ROOT_PATH/vbooking/scripts/services/vbtomcat /etc/init.d/
chkconfig --add vbtomcat
chkconfig vbtomcat on

echo "Starting Tomcat"
service vbtomcat start

echo "Tomcat installed and configured!"
